#' List of all data objects used for the solitary tinamou vignette.
#' @name SolitaryTinamou
#' @docType data
#' @keywords data
NULL

#' data.frame object containing solitary tinamou observations from eBird
#' @name eBird
#' @docType data
#' @keywords data
#' @references \url{http://ebird.org/}
NULL

#' data.frame object containing solitary tinamou observations from Parks
#' @name Parks
#' @docType data
#' @keywords data
#' @source \url{https://www.gbif.org/}
NULL

#' data.frame object containing solitary tinamou observations from Gbif
#' @name Gbif
#' @docType data
#' @keywords data
#' @source \url{https://www.gbif.org/}
NULL

#' spatRaster object containing covariate values
#' @name SolTinCovariates
#' @docType data
#' @keywords data
#' @source \url{https://github.com/oharar/PointedSDMs}
NULL

#' sf object containing the boundary region for solitary tinamouc 
#' @name region
#' @docType data
#' @keywords data
#' @source \url{https://github.com/oharar/PointedSDMs}
NULL


